@@ -36,12 +36,12 @@ def check_and_ask(config):
 
 def parse_config():
     config_files = [
+        os.path.join(os.path.expanduser("/opt/robin/config/sd-upload"), "sd-upload-config.yml"),
+        os.path.join(os.path.expanduser("/opt/robin/config/sd-upload"), "sd-upload-config.yaml"),
         os.path.join(os.path.expanduser("~"), ".sd-upload-config.yml"),
         os.path.join(os.path.expanduser("~"), ".sd-upload-config.yaml"),
         "sd-upload-config.yml",
-        "sd-upload-config.yaml",
-        os.path.join(os.path.expanduser("/opt/robin/config/sd-upload"), "sd-upload-config.yml"),
-        os.path.join(os.path.expanduser("/opt/robin/config/sd-upload"), "sd-upload-config.yaml"),
+        "sd-upload-config.yaml"
     ]
 
     config = None
